<?php
/**
 * Plugin Name: Grove Testimonials
 * Plugin URI: http://g5plus.net
 * Description: This is plugin that create our team post type
 * Version: 1.0
 * Author: g5plus
 * Author URI: http://g5plus.net
 * License: GPLv2 or later
 */

// don't load directly
if ( ! defined( 'ABSPATH' ) ) die( '-1' );
if(!class_exists('Grove_Testimonial')){
    class Grove_Testimonial{
        function __construct(){
            add_action('init', array($this,'register_post_types'), 5 );
            add_shortcode('grove_testimonial', array($this, 'grove_testimonial_shortcode'));
            add_filter( 'rwmb_meta_boxes', array($this,'grove_register_meta_boxes' ));
        }
        function grove_register_meta_boxes( $meta_boxes )
        {
            // Testimonials Options
            $meta_boxes[] = array(
                'title'  => __( 'Testimonials Information', 'grove' ),
                'pages'  => array( 'testimonials' ),
                'fields' => array(
                    array(
                        'name' => __( 'Job', 'grove' ),
                        'id'   => 'job',
                        'type' => 'text',
                    ),
                    array(
                        'name' => __( 'Website', 'grove' ),
                        'id'   => 'website',
                        'type' => 'text',
                    ),
                )
            );
            return $meta_boxes;
        }
        function register_post_types() {
            if ( post_type_exists('testimonials') ) {
                return;
            }

            register_post_type( 'testimonials',
                array(
                    'label'       => __( 'grove_testimonials', 'grove' ),
                    'description' => __( 'Testimonials Description', 'grove' ),
                    'labels'      => array(
                        'name'               => _x( 'Testimonials', 'Post Type General Name', 'grove' ),
                        'singular_name'      => _x( 'Testimonials', 'Post Type Singular Name', 'grove' ),
                        'menu_name'          => __( 'Testimonials', 'grove' ),
                        'all_items'          => __( 'All Testimonials', 'grove' ),
                        'add_new_item'       => __( 'Add New Testimonials', 'grove' ),
                    ),
                    'supports'    => array( 'title', 'excerpt', 'thumbnail'),
                    'public'      => true,
                    'has_archive' => true
                )
            );

        }
        function grove_testimonial_shortcode($atts){
            $title=$layout_style=$item_amount = $column = $scheme_style = $html = $el_class = $g5plus_animation = $css_animation = $duration = $delay = $styles_animation = '';
            extract( shortcode_atts( array(
                'layout_style'  => '',
                'title'         => '',
                'column'        => '',
                'item_amount'   => '',
                'scheme_style'  => '',
                'el_class'      => '',
                'css_animation' => '',
                'duration'      => '',
                'delay'         => ''
            ), $atts ) );

            $g5plus_animation .= ' ' . esc_attr($el_class);
            $g5plus_animation .= g5plus_getCSSAnimation( $css_animation );
            $styles_animation= g5plus_getStyleAnimation($duration,$delay);

            $args    = array(
                'posts_per_page'   	=> $item_amount,
                'post_type'      => 'testimonials',
                'orderby'   => 'date',
                'order'     => 'ASC',
                'post_status'      	=> 'publish'
            );
            $data = new WP_Query( $args );
            if ( $data->have_posts() ) {
                $number_id = rand( 0, 10000 );$i=0;
                if($layout_style=='style1')
                {
                    $html .= '<div id="testimonials-'.$number_id.'" class="testimonials-wapper ' .esc_attr($layout_style) . esc_attr($g5plus_animation) . ' '.esc_attr($scheme_style). '" '.$styles_animation .'>
                            <div class="container">
                               <div class="row">
                                <div class="testimonials-text-mask"></div>
                                <div class="owl-carousel" data-plugin-options=\'{"items" : '.esc_attr($column).',"pagination": false,"autoPlay":10000, "afterInit" : "Core.afterInit_testimonial(this.visibleItems,'.$number_id.')", "afterMove" : "Core.afterMove_testimonial(this.visibleItems,'.$number_id.')"}\'>';
                    while ( $data->have_posts() ): $data->the_post();
                        $i++;
                        $job   = get_post_meta(get_the_ID(), 'job', true);
                        $image_id  = get_post_thumbnail_id();
                        $image_url = wp_get_attachment_image( $image_id, 'full', false, array( 'alt' => get_the_title(), 'title' => get_the_title()));
                        $html .= '<div class="testimonials-item" data-current_item="'.$i.'">
                                <div class="testimonials-text">
                                  ' . get_the_excerpt() . '
                                </div>
                                 <div class="testimonials-info"><p>' . get_the_title() . ',</p> <span>'.esc_attr($job).'</span></div>
                                '.$image_url.'
                             </div>';
                    endwhile;
                    $html .= '</div>
                                </div>
                            </div>
                       </div>';
                }
                else
                {
                    $html .= '<div id="testimonials-'.$number_id.'" class="testimonials-wapper ' .esc_attr($layout_style) . esc_attr($g5plus_animation) . ' '.esc_attr($scheme_style). '" '.$styles_animation .'>';
                                 if($title!='' && $layout_style=='style2')
                                 {
                                     $html .= '<h2>'.$title.'</h2>';
                                 }
                        $html .= '<div class="owl-carousel" data-plugin-options=\'{"singleItem" : true,"pagination": false,"navigation": true,"autoPlay":10000}\'>';
                    while ( $data->have_posts() ): $data->the_post();
                        $i++;
                        $job   = get_post_meta(get_the_ID(), 'job', true);
                        $website   = get_post_meta(get_the_ID(), 'website', true);
                        $html .= '<div class="testimonials-item content-middle">
                                    <div class="content-middle-inner">
                                        <div class="testimonials-text">
                                          ' . get_the_excerpt() . '
                                        </div>
                                        <div class="testimonials-info"><p>' . get_the_title() . ',</p> <span>'.esc_attr($job).'</span>
                                            <br/>
                                            <a href="'.$website.'">'.$website.'</a>
                                        </div>
                                    </div>
                                 </div>';
                    endwhile;
                    $html .= '</div>
                       </div>';
                }
            }
            wp_reset_postdata();
            return $html;
        }
    }
    new Grove_Testimonial;
}